module.exports = defineTest({
	description: 'export from works with default exports'
});

// test copied from https://github.com/esnext/es6-module-transpiler/tree/master/test/examples/export-from-default
